/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package chtdecoder.datastructures;

import java.util.NoSuchElementException;

/**
 * An iterator for CHTCode objects.
 *
 * @author John David Ratliff
 * @version 1.2, 10/22/04
 */
public interface CHTCodeIterator {
    /**
     * Queries if this iterator has more elements.
     *
     * @return true if more elements remain; false otherwise.
     */
    public boolean hasMore();

    /**
     * Gets the next CHTCode from this iterator.
     *
     * @return The next CHTCode in this iterator.
     *
     * @throws NoSuchElementException if no more elements are in this
     *         iterator.
     */
    public CHTCode next() throws NoSuchElementException;

    /**
     * Returns the number of items remaining in this CHTCodeIterator.
     *
     * @return The remaining item count.
     */
    public int remain();
}
